
***********************************************************
***********************************************************
*
* In Wrong Anticipation - Miscalibrated Beliefs on Trust
* S.J. Goerg, H. Hennig-Schmidt, G. Walkowitz, and E. Winter
*
***********************************************************
***********************************************************

* Adjust working directory! 
* cd "xxxx/xxxx/xxxx"

use "Data.dta", clear
set more off

***********************************************************
***********************************************************


* Trust standards within locations: 
table Study Location_ID if Same_Location , contents(mean Transfer sd Transfer mean Belief_Transfer sd Belief_Transfer )

* Differences between transfers and expected transfers within location
preserve
	generate Test_Trust = Belief_Transfer
	replace Test_Trust = Transfer if Test_Trust == .
	set seed 88888888
	bysort Study Location_ID: permtest2 Test_Trust if Same_Location, by(Sender)
	quietly{
	generate mtransfer_to_location = . 
	******* Study 1 ****************
	replace mtransfer_to_location = 3.9 if (Location_Jerusalem & Matched_to_Jerusalem) & Study ==1 & Sender == 0
	replace mtransfer_to_location = 6.7 if (Location_AbuDis & Matched_to_AbuDis) & Study ==1 & Sender == 0
	replace mtransfer_to_location = 4.4 if (Location_Bonn & Matched_to_Bonn) & Study ==1 & Sender == 0
	******* Study 2 ****************
	replace mtransfer_to_location = 4.3 if (Location_Jerusalem & Matched_to_Jerusalem) & Study ==2 & Sender == 0
	replace mtransfer_to_location = 8 if (Location_AbuDis & Matched_to_AbuDis) & Study ==2 & Sender == 0
	replace mtransfer_to_location = 6 if (Location_Bonn & Matched_to_Bonn) & Study ==2 & Sender == 0
	}
	spearman mtransfer_to_location Belief_Transfer if Same_Location & Study ==1
	spearman mtransfer_to_location Belief_Transfer if Same_Location & Study ==2
restore

***********************************************************
***********************************************************

* Differences in transfers between locations

kwallis Transfer if Same_Location & Study ==1, by(Location_ID)
kwallis Transfer if Same_Location & Study ==2, by(Location_ID)
set seed 88888888
bysort Study: permtest2 Transfer if Same_Location & (Location_Bonn | Location_Jerusalem), by(Location_ID)
bysort Study: permtest2 Transfer if Same_Location & (Location_AbuDis | Location_Jerusalem), by(Location_ID)
bysort Study: permtest2 Transfer if Same_Location & (Location_Bonn | Location_AbuDis), by(Location_ID)


* Differences between expected transfers between locations

kwallis Belief_Transfer if Same_Location & Study ==1 , by(Location_ID)
kwallis Belief_Transfer if Same_Location & Study ==2 , by(Location_ID)
set seed 88888888
bysort Study: permtest2 Belief_Transfer if Same_Location & (Location_Bonn | Location_Jerusalem), by(Location_ID)
bysort Study: permtest2 Belief_Transfer if Same_Location & (Location_AbuDis | Location_Jerusalem), by(Location_ID)
bysort Study: permtest2 Belief_Transfer if Same_Location & (Location_Bonn | Location_AbuDis), by(Location_ID)

***********************************************************
***********************************************************

* Discrimination between countries

set seed 88888888
permtest2 Transfer if Location_Bonn & (Matched_to_Jerusalem | Matched_to_Bonn) & Study == 2, by(Matched_to_ID)
permtest2 Transfer if Location_Bonn & (Matched_to_AbuDis | Matched_to_Bonn) & Study == 2, by(Matched_to_ID)
permtest2 Transfer if Location_AbuDis & (Matched_to_Jerusalem | Matched_to_AbuDis) & Study == 2, by(Matched_to_ID)
permtest2 Transfer if Location_AbuDis & (Matched_to_AbuDis | Matched_to_Bonn) & Study == 2, by(Matched_to_ID)
permtest2 Transfer if Location_Jerusalem & (Matched_to_Jerusalem | Matched_to_Bonn) & Study == 2, by(Matched_to_ID)
permtest2 Transfer if Location_Jerusalem & (Matched_to_AbuDis | Matched_to_Jerusalem) & Study == 2, by(Matched_to_ID)

preserve 
	* Bonn vs. Jeru
	bysort ID : egen other = mean(Transfer) if Location_Bonn & Matched_to_Jerusalem & Study ==1 
	bysort ID : egen Test_other = mean(other)
	permtest1 Transfer = Test_other if Same_Location
	drop other Test_other
	* Bonn vs. AbuDis
	bysort ID : egen other = mean(Transfer) if Location_Bonn & Matched_to_AbuDis & Study ==1 
	bysort ID : egen Test_other = mean(other)
	permtest1 Transfer = Test_other if Same_Location
	drop other Test_other
	* AbuDis vs. Jeru
	bysort ID : egen other = mean(Transfer) if Location_AbuDis & Matched_to_Jerusalem & Study ==1 
	bysort ID : egen Test_other = mean(other)
	permtest1 Transfer = Test_other if Same_Location
	drop other Test_other
	* AbuDis vs. Bonn
	bysort ID : egen other = mean(Transfer) if Location_AbuDis & Matched_to_Bonn & Study ==1 
	bysort ID : egen Test_other = mean(other)
	permtest1 Transfer = Test_other if Same_Location
	drop other Test_other
	* Jeru vs. AbuDis
	bysort ID : egen other = mean(Transfer) if Location_Jerusalem & Matched_to_AbuDis & Study ==1 
	bysort ID : egen Test_other = mean(other)
	permtest1 Transfer = Test_other if Same_Location
	drop other Test_other
	* Jeru vs. Bonn
	bysort ID : egen other = mean(Transfer) if Location_Jerusalem & Matched_to_Bonn & Study ==1 
	bysort ID : egen Test_other = mean(other)
	permtest1 Transfer = Test_other if Same_Location
	drop other Test_other
restore

***********************************************************
***********************************************************

* Miscalibration of beliefs
preserve 
	generate Test_Trust = Belief_Transfer
	replace Test_Trust = Transfer if Test_Trust == .
	set seed 88888888
	*Test difference between actual transfer and expected tranmeavs.sfer for each location and each matching
	bysort Study: permtest2 Test_Trust if (Matched_to_AbuDis & Location_Jerusalem & Sender == 0) | (Location_AbuDis & Matched_to_Jerusalem & Sender == 1), by(Sender)
	bysort Study: permtest2 Test_Trust if (Matched_to_Bonn & Location_Jerusalem & Sender == 0) | (Location_Bonn & Matched_to_Jerusalem & Sender == 1), by(Sender)
	bysort Study: permtest2 Test_Trust if (Location_Jerusalem & Same_Location), by(Sender)
	bysort Study: permtest2 Test_Trust if (Matched_to_Jerusalem & Location_AbuDis & Sender == 0) | (Location_Jerusalem & Matched_to_AbuDis & Sender == 1), by(Sender)
	bysort Study: permtest2 Test_Trust if (Matched_to_Bonn & Location_AbuDis & Sender == 0) | (Location_Bonn & Matched_to_AbuDis & Sender == 1), by(Sender)
	bysort Study: permtest2 Test_Trust if (Location_AbuDis & Same_Location), by(Sender)	
	bysort Study: permtest2 Test_Trust if (Matched_to_Jerusalem & Location_Bonn & Sender == 0) | (Location_Jerusalem & Matched_to_Bonn & Sender == 1), by(Sender)
	bysort Study: permtest2 Test_Trust if (Matched_to_AbuDis & Location_Bonn & Sender == 0) | (Location_AbuDis & Matched_to_Bonn & Sender == 1), by(Sender)
	bysort Study: permtest2 Test_Trust if (Location_Bonn & Same_Location), by(Sender)
		
	*Test adaption of belief if not matched with own subject-pool (all p>.22)
	*Study 1
	* Bonn vs. Jeru
	bysort ID : egen other = mean(Belief_Transfer) if Location_Bonn & Matched_to_Jerusalem & Study ==1 
	bysort ID : egen Test_other = mean(other)
	permtest1 Belief_Transfer = Test_other if Same_Location
	drop other Test_other
	* Bonn vs. AbuDis
	bysort ID : egen other = mean(Belief_Transfer) if Location_Bonn & Matched_to_AbuDis & Study ==1 
	bysort ID : egen Test_other = mean(other)
	permtest1 Belief_Transfer = Test_other if Same_Location
	drop other Test_other
	* AbuDis vs. Jeru
	bysort ID : egen other = mean(Belief_Transfer) if Location_AbuDis & Matched_to_Jerusalem & Study ==1 
	bysort ID : egen Test_other = mean(other)
	permtest1 Belief_Transfer = Test_other if Same_Location
	drop other Test_other
	* AbuDis vs. Bonn
	bysort ID : egen other = mean(Belief_Transfer) if Location_AbuDis & Matched_to_Bonn & Study ==1 
	bysort ID : egen Test_other = mean(other)
	permtest1 Belief_Transfer = Test_other if Same_Location
	drop other Test_other
	* Jeru vs. AbuDis
	bysort ID : egen other = mean(Belief_Transfer) if Location_Jerusalem & Matched_to_AbuDis & Study ==1 
	bysort ID : egen Test_other = mean(other)
	permtest1 Belief_Transfer = Test_other if Same_Location
	drop other Test_other
	* Jeru vs. Bonn
	bysort ID : egen other = mean(Belief_Transfer) if Location_Jerusalem & Matched_to_Bonn & Study ==1 
	bysort ID : egen Test_other = mean(other)
	permtest1 Belief_Transfer = Test_other if Same_Location
	drop other Test_other
	*Study 2
	permtest2 Belief_Transfer if Location_Bonn & (Matched_to_AbuDis | Matched_to_Bonn) & Study ==2 , by(Matched_to_ID)
    permtest2 Belief_Transfer if Location_Bonn & (Matched_to_Jerusalem | Matched_to_Bonn)& Study ==2, by(Matched_to_ID)
	permtest2 Belief_Transfer if Location_AbuDis & (Matched_to_AbuDis | Matched_to_Bonn)& Study ==2, by(Matched_to_ID)
	permtest2 Belief_Transfer if Location_AbuDis & (Matched_to_Jerusalem | Matched_to_AbuDis)& Study ==2, by(Matched_to_ID)
	permtest2 Belief_Transfer if Location_Jerusalem & (Matched_to_AbuDis | Matched_to_Jerusalem)& Study ==2, by(Matched_to_ID)
	permtest2 Belief_Transfer if Location_Jerusalem & (Matched_to_Jerusalem | Matched_to_Bonn)& Study ==2, by(Matched_to_ID)
	
	
	*Test accuracy expectation  inter subject-pool versus intra subject pool 
	quietly{
	generate mtransfer_to_location = . 	
	******* Study 1 ****************
	replace mtransfer_to_location = 3.9 if (Matched_to_Jerusalem & Location_Jerusalem) & Study ==1 & Sender == 0
	replace mtransfer_to_location = 6.7 if (Matched_to_AbuDis & Location_AbuDis) & Study ==1 & Sender == 0
	replace mtransfer_to_location = 4.4 if (Matched_to_Bonn & Location_Bonn) & Study ==1 & Sender == 0
	replace mtransfer_to_location = 2.9 if (Matched_to_Jerusalem & Location_AbuDis) & Study ==1  & Sender == 0
	replace mtransfer_to_location = 6.9 if (Matched_to_AbuDis & Location_Bonn) & Study ==1 & Sender == 0
	replace mtransfer_to_location = 5.2 if (Matched_to_Bonn & Location_Jerusalem) & Study ==1 & Sender == 0
	replace mtransfer_to_location = 3.9 if (Matched_to_Jerusalem & Location_Bonn) & Study ==1 & Sender == 0
	replace mtransfer_to_location = 6.2 if (Matched_to_AbuDis & Location_Jerusalem) & Study ==1 & Sender == 0
	replace mtransfer_to_location = 5.6 if (Matched_to_Bonn & Location_AbuDis) & Study ==1 & Sender == 0

	******* Study 2 ****************
	replace mtransfer_to_location = 4.3 if (Location_Jerusalem & Matched_to_Jerusalem) & Study ==2 & Sender == 0
	replace mtransfer_to_location = 8 if (Location_AbuDis & Matched_to_AbuDis) & Study ==2 & Sender == 0
	replace mtransfer_to_location = 6 if (Location_Bonn & Matched_to_Bonn) & Study ==2 & Sender == 0
	replace mtransfer_to_location = 4.1 if (Matched_to_Jerusalem & Location_AbuDis) & Study ==2 & Sender == 0
	replace mtransfer_to_location = 7.6 if (Matched_to_AbuDis & Location_Bonn) & Study ==2 & Sender == 0
	replace mtransfer_to_location = 7.1 if (Matched_to_Bonn & Location_Jerusalem) & Study ==2 & Sender == 0
	replace mtransfer_to_location = 6.3 if (Matched_to_Jerusalem & Location_Bonn) & Study ==2 & Sender == 0
	replace mtransfer_to_location = 6.5 if (Matched_to_AbuDis & Location_Jerusalem) & Study ==2 & Sender == 0
	replace mtransfer_to_location = 5.3 if (Matched_to_Bonn & Location_AbuDis) & Study ==2 & Sender == 0
	}
	generate diff = abs(Belief_Transfer - mtransfer_to_location)
	set seed 88888888
	permtest2 diff if Study == 2 , by(Same_Location)

	bysort ID : egen other = mean(diff) if Same_Location == 0 & Study ==1 
	bysort ID : egen Test_other = mean(other)
	permtest1 diff = Test_other if Same_Location & Study ==1 

restore



* In accurate beliefs on backtransfers across all subject-pools.
preserve	
	permtest1 Belief = AvBackTransfer if  Location_Bonn & Matched_to_ID == 1 & Study == 1
	permtest1 Belief = AvBackTransfer if  Location_Bonn & Matched_to_ID == 2 & Study == 1
	permtest1 Belief = AvBackTransfer if Location_Bonn & Matched_to_ID == 3 & Study == 1
	permtest1 Belief = AvBackTransfer if  Location_Bonn & Matched_to_ID == 1 & Study == 2
	permtest1 Belief = AvBackTransfer if  Location_Bonn & Matched_to_ID == 2 & Study == 2
	permtest1 Belief = AvBackTransfer if Location_Bonn & Matched_to_ID == 3 & Study == 2

	permtest1 Belief = AvBackTransfer if  Location_AbuDis & Matched_to_ID == 1 & Study == 1
	permtest1 Belief = AvBackTransfer if  Location_AbuDis & Matched_to_ID == 2 & Study == 1
	permtest1 Belief = AvBackTransfer if Location_AbuDis & Matched_to_ID == 3 & Study == 1
	permtest1 Belief = AvBackTransfer if  Location_AbuDis & Matched_to_ID == 1 & Study == 2
	permtest1 Belief = AvBackTransfer if  Location_AbuDis & Matched_to_ID == 2 & Study == 2
	permtest1 Belief = AvBackTransfer if Location_AbuDis & Matched_to_ID == 3 & Study == 2

	permtest1 Belief = AvBackTransfer if  Location_Jerusalem & Matched_to_ID == 1 & Study == 1
	permtest1 Belief = AvBackTransfer if  Location_Jerusalem & Matched_to_ID == 2 & Study == 1
	permtest1 Belief = AvBackTransfer if Location_Jerusalem & Matched_to_ID == 3 & Study == 1
	permtest1 Belief = AvBackTransfer if  Location_Jerusalem & Matched_to_ID == 1 & Study == 2
	permtest1 Belief = AvBackTransfer if  Location_Jerusalem & Matched_to_ID == 2 & Study == 2
	permtest1 Belief = AvBackTransfer if Location_Jerusalem & Matched_to_ID == 3 & Study == 2
restore

preserve	
	generate  diff_back = (AvBackTransfer-Belief) if Sender	
	generate Sender2 = 1 if Location_Jerusalem
	replace Sender2 = 2 if Location_AbuDis
	replace Sender2 = 3 if Location_Bonn
	generate Responder = 1 if Matched_to_ID == 3
	replace Responder = 2 if Matched_to_ID == 2
	replace Responder = 3 if Matched_to_ID == 1
	sum  Belief AvBackTransfer if  Location_Bonn & Matched_to_ID == 2 & Study == 1
	sum  Belief AvBackTransfer if  Location_Jerusalem & Matched_to_ID == 2 & Study == 1
	graph hbar (mean) diff_back , blabel(total)  over(Responder, relabel(1 "Israel" 2 "Palestine" 3 "Germany")) over(Sender2, relabel(1 "Israel" 2 "Palestine" 3 "Germany") ) bar(1, fcolor(gs8)) nofill scheme(s2mono) by(, cols(1) note("") graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))) by(Study) subtitle(, fcolor(white) lcolor(white))
restore

* No Difference in accuracy of beliefs on backtransfers
preserve
	generate  diff_back = abs((Belief-AvBackTransfer)) if Sender	& Transfer > 0
	bysort ID : egen mean_error = mean(diff_back) if Same_Location==0
	bysort ID: egen diff_back_other = mean(mean_error)
	sum diff_back diff_back_other if Study == 1 & Sender& Same_Location
	bysort Same_Location: sum diff_back if Study ==2
	permtest1 diff_back = diff_back_other if Study == 1 & Sender& Same_Location
	permtest2 diff_back if Study == 2 & Sender, by(Same_Location)
restore


* No systematic negative discrmination in beliefs on backtransfers from other locations 
preserve
	bysort ID : egen Gb = mean(Belief) if Matched_to_Bonn==1
	bysort ID: egen GBelief = mean(Gb)
	bysort ID : egen Ab = mean(Belief) if Matched_to_AbuDis==1
	bysort ID: egen ABelief = mean(Ab)
	bysort ID : egen Jb = mean(Belief) if Matched_to_Jerusalem==1
	bysort ID: egen JBelief = mean(Jb)
	
	permtest1 Belief = ABelief if Study == 1 & Sender& Same_Location & Location_Jerusalem
	permtest1 Belief = GBelief if Study == 1 & Sender& Same_Location & Location_Jerusalem
	permtest1 Belief = GBelief if Study == 1 & Sender& Same_Location & Location_AbuDis
	permtest1 Belief = JBelief if Study == 1 & Sender& Same_Location & Location_AbuDis
	permtest1 Belief = ABelief if Study == 1 & Sender& Same_Location & Location_Bonn
	permtest1 Belief = JBelief if Study == 1 & Sender& Same_Location & Location_Bonn

	permtest2 Belief if Study == 2 & Sender, by(Same_Location)
	permtest2 Belief if Study == 2 & Sender & Location_Jerusalem, by(Same_Location)
	permtest2 Belief if Study == 2 & Sender & Location_AbuDis, by(Same_Location)
	permtest2 Belief if Study == 2 & Sender & Location_Bonn, by(Same_Location)	
	permtest2 Belief if Study == 2 & Sender & Location_Jerusalem & (Matched_to_Bonn | Matched_to_Jerusalem), by(Same_Location)
	permtest2 Belief if Study == 2 & Sender & Location_Jerusalem & (Matched_to_AbuDis | Matched_to_Jerusalem), by(Same_Location)
	permtest2 Belief if Study == 2 & Sender & Location_Bonn & (Matched_to_Bonn | Matched_to_Jerusalem), by(Same_Location)
	permtest2 Belief if Study == 2 & Sender & Location_Bonn & (Matched_to_Bonn |Matched_to_AbuDis), by(Same_Location)
	permtest2 Belief if Study == 2 & Sender & Location_AbuDis & (Matched_to_Bonn | Matched_to_AbuDis), by(Same_Location)
	permtest2 Belief if Study == 2 & Sender & Location_AbuDis & (Matched_to_AbuDis | Matched_to_Jerusalem), by(Same_Location)
restore


